pub struct DebugProcessNode {
pub print: bool,
}Expand description
A simple debug node for testing that just echoes its input.
Fields
print: boolTrait Implementations
Sourceimpl Clone for DebugProcessNode
impl Clone for DebugProcessNode
Sourcefn clone(&self) -> DebugProcessNode
fn clone(&self) -> DebugProcessNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DebugProcessNode
impl Debug for DebugProcessNode
Sourceimpl Default for DebugProcessNode
impl Default for DebugProcessNode
Sourceimpl<'de> Deserialize<'de> for DebugProcessNode
impl<'de> Deserialize<'de> for DebugProcessNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DebugProcessNode
impl JsonSchema for DebugProcessNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl NodeType for DebugProcessNode
impl NodeType for DebugProcessNode
fn type_name(&self) -> String
fn process<'life0, 'life1, 'async_trait>(
&'life0 self,
input: Message,
context: &'life1 mut NodeContext,
) -> Pin<Box<dyn Future<Output = Result<NodeOut, NodeErr>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn clone_box(&self) -> Box<dyn NodeType>
Sourceimpl PartialEq for DebugProcessNode
impl PartialEq for DebugProcessNode
Sourcefn eq(&self, other: &DebugProcessNode) -> bool
fn eq(&self, other: &DebugProcessNode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DebugProcessNode
impl Serialize for DebugProcessNode
impl StructuralPartialEq for DebugProcessNode